Seashore
========

.. image:: https://travis-ci.org/shopkick/seashore.svg?branch=master
    :target: https://travis-ci.org/shopkick/seashore

.. image:: https://readthedocs.org/projects/seashore/badge/?version=latest
    :target: http://seashore.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

Seashore provides a shell abstraction
for easy automation of UNIX commands in Python.
The primary interface to many common tools is the command line;
for example, :code:`git`, :code:`apt-get`, and :code:`yum`.
Even when there is an equivalent Python library --
such as :code:`docker` and :code:`docker-py` --
often a shell script needs to be quickly ported one-to-one.
Seashore helps in these cases by being able to write a
clean, simple, and testable Python API wrapper around
these tools.

License
-------

Seashore is (C) 2017-2020 Contributors, and licensed under the MIT license.
See the LICENSE file for more details.

History
-------

Seashore was originally released by Shopkick.
Since then,
it has been forked and is part of the El Camino Real
suit.

Contributors
------------

* Moshe Zadka
* Mahmoud Hashemi
* Kurt B. Rose
